Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ExecutionResult ¶
type FileSystem ¶
FileSystem provides read and write access to a file system.
type ReadFS ¶
ReadFS provides read access to a file system. ReadFS has support for context.Context in addition to the similar fs.FS.
type System ¶
type System interface {
io.Closer
FileSystem
Executor
}
System is an interface to access a file system of and execute commands on a system.
type WriteFS ¶
type WriteFS interface {
// Create creates or truncates the named file. If the file already exists,
// it is truncated. If the file does not exist, it is created.
// The size of the file must be known in advance.
Create(ctx context.Context, fileInfo fs.FileInfo) (WriteFile, error)
}
WriteFS provides write access to a file system.
Click to show internal directories.
Click to hide internal directories.